{
    "$graph": [
        {
            "class": "Workflow",
            "id": "#main",
            "label": "workflow to generate mapping stats, counts and fusion events",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "FASTA file of a reference file, which the input BAM file was mapped to.",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#main/bigwig_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for generating bigwig.",
                    "id": "#main/bigwig_threads"
                },
                {
                    "type": "File",
                    "doc": "A reference GTF file.",
                    "id": "#main/count_reference"
                },
                {
                    "type": "File",
                    "doc": "Defuse reference bundle tar file.",
                    "id": "#main/defuse_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for tophat fusion process.",
                    "id": "#main/defuse_threads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "string"
                        ]
                    },
                    "doc": "Description tag value in the output BAM header. It should have one value for each group of input raw files. Use empty string to set it to none or existing DS tag in the input BAM. It only uses the DS tag value in the first BAM file of a group.",
                    "id": "#main/ds_tags"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "string"
                        ]
                    },
                    "doc": "Sequencing library tag values in the output BAM header. It should have one value for each group of input raw files. Use empty string to set it to none or existing LB tag in the input BAM. It only uses the LB tag value in the first BAM file of a group.",
                    "id": "#main/lb_tags"
                },
                {
                    "type": "File",
                    "doc": "The core STAR reference and a GTF file bundled in a tar.gz.",
                    "id": "#main/map_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for each mapping process.",
                    "id": "#main/map_threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for merging step.",
                    "id": "#main/merge_threads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "string"
                        ]
                    },
                    "doc": "Platform tag value in the output BAM header. It should have one value for each group of input raw files. Use empty string to set it to none or existing PL tag in the input BAM. It only uses the PL tag value in the first BAM file of a group.",
                    "id": "#main/pl_tags"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "string"
                        ]
                    },
                    "doc": "Platform unit tag value in the output BAM header. It should have one value for each group of input raw files. Use empty string to set it to none or existing PU tag in the input BAM. It only uses the PU tag value in the first BAM file of a group.",
                    "id": "#main/pu_tags"
                },
                {
                    "doc": "RAW read input, can be BAM files or pairs of FastQ files (optionally gzip compressed). Each element of this array will be treated as one read group in the aligned BAM file. Within each element, only either BAM files or FastQ files are allowed.",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/raw_reads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "string"
                        ]
                    },
                    "doc": "Readgroup ID tag values. It should have one value for each group of input raw files. Use empty string to use defaults or existing RG ID in the input BAM. It only uses the RG ID value in the first BAM file of a group.",
                    "id": "#main/rg_id_tags"
                },
                {
                    "type": "string",
                    "doc": "Sample name, which will used to prefix output file names and SM tag in the BAM file header.",
                    "default": "",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for tophat fusion process.",
                    "id": "#main/star_threads"
                },
                {
                    "type": "File",
                    "doc": "The reference files bundled in a tar.gz.",
                    "id": "#main/stats_reference"
                },
                {
                    "type": "File",
                    "doc": "Tophat fusion reference bundle tar file.",
                    "id": "#main/tophat_fusion_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for tophat fusion process.",
                    "id": "#main/tophat_threads"
                },
                {
                    "type": "File",
                    "doc": "VAGrENT cache file that should be the same reference and gene build as the GTF file.",
                    "secondaryFiles": [
                        ".tbi",
                        "$(self.basename.replace(\"cache.gz\", \"fa\"))",
                        "$(self.basename.replace(\"cache.gz\", \"fa.fai\"))"
                    ],
                    "id": "#main/vagrent_cache"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/bigwig_reference",
                            "id": "#main/bigwig/reference"
                        },
                        {
                            "source": "#main/merge/dup_marked_merged_bam",
                            "id": "#main/bigwig/sample_bam"
                        },
                        {
                            "source": "#main/bigwig_threads",
                            "id": "#main/bigwig/threads"
                        }
                    ],
                    "out": [
                        "#main/bigwig/out_bw"
                    ],
                    "run": "#run-cgprna_bigwig.cwl",
                    "id": "#main/bigwig"
                },
                {
                    "in": [
                        {
                            "source": "#main/count_reference",
                            "id": "#main/count/reference"
                        },
                        {
                            "source": "#main/merge/dup_marked_merged_bam",
                            "id": "#main/count/sample_bam"
                        }
                    ],
                    "out": [
                        "#main/count/out_count"
                    ],
                    "run": "#run-cgprna_htseq-count.cwl",
                    "id": "#main/count"
                },
                {
                    "in": [
                        {
                            "source": "#main/defuse_reference",
                            "id": "#main/infuse/defuse_reference"
                        },
                        {
                            "source": "#main/defuse_threads",
                            "id": "#main/infuse/defuse_threads"
                        },
                        {
                            "source": "#main/count_reference",
                            "id": "#main/infuse/gtf"
                        },
                        {
                            "source": "#main/merge/dup_marked_merged_bam",
                            "id": "#main/infuse/in_bam"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/infuse/sample_name"
                        },
                        {
                            "source": "#main/map_reference",
                            "id": "#main/infuse/star_reference"
                        },
                        {
                            "source": "#main/star_threads",
                            "id": "#main/infuse/star_threads"
                        },
                        {
                            "source": "#main/tophat_fusion_reference",
                            "id": "#main/infuse/tophat_fusion_reference"
                        },
                        {
                            "source": "#main/tophat_threads",
                            "id": "#main/infuse/tophat_threads"
                        },
                        {
                            "source": "#main/vagrent_cache",
                            "id": "#main/infuse/vagrent_cache"
                        }
                    ],
                    "out": [
                        "#main/infuse/tophat_fusions",
                        "#main/infuse/star_fusions",
                        "#main/infuse/defuse_fusions",
                        "#main/infuse/combined_fusions"
                    ],
                    "run": "#infuse_pipeline.cwl",
                    "id": "#main/infuse"
                },
                {
                    "in": [
                        {
                            "source": "#main/ds_tags",
                            "id": "#main/map_and_stats/ds_tag"
                        },
                        {
                            "source": "#main/lb_tags",
                            "id": "#main/map_and_stats/lb_tag"
                        },
                        {
                            "source": "#main/map_reference",
                            "id": "#main/map_and_stats/map_reference"
                        },
                        {
                            "source": "#main/map_threads",
                            "id": "#main/map_and_stats/map_threads"
                        },
                        {
                            "source": "#main/pl_tags",
                            "id": "#main/map_and_stats/pl_tag"
                        },
                        {
                            "source": "#main/pu_tags",
                            "id": "#main/map_and_stats/pu_tag"
                        },
                        {
                            "source": "#main/raw_reads",
                            "id": "#main/map_and_stats/raw_reads"
                        },
                        {
                            "source": "#main/rg_id_tags",
                            "id": "#main/map_and_stats/rg_id_tag"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/map_and_stats/sample_name"
                        },
                        {
                            "source": "#main/stats_reference",
                            "id": "#main/map_and_stats/stats_reference"
                        }
                    ],
                    "out": [
                        "#main/map_and_stats/dup_marked_bam",
                        "#main/map_and_stats/dup_marked_bam_dup_met",
                        "#main/map_and_stats/transcriptome_bam",
                        "#main/map_and_stats/rna_bas",
                        "#main/map_and_stats/gene_cover_png",
                        "#main/map_and_stats/gene_body_coverage_rscript",
                        "#main/map_and_stats/gene_body_coverage_txt",
                        "#main/map_and_stats/gene_body_coverage_updated_rscript",
                        "#main/map_and_stats/read_dist"
                    ],
                    "scatter": [
                        "#main/map_and_stats/raw_reads",
                        "#main/map_and_stats/rg_id_tag",
                        "#main/map_and_stats/lb_tag",
                        "#main/map_and_stats/ds_tag",
                        "#main/map_and_stats/pl_tag",
                        "#main/map_and_stats/pu_tag"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#lane_map_and_stats.cwl",
                    "id": "#main/map_and_stats"
                },
                {
                    "in": [
                        {
                            "source": "#main/sample_name",
                            "valueFrom": "$(self).bam.met",
                            "id": "#main/merge/dup_met_file_name"
                        },
                        {
                            "source": "#main/sample_name",
                            "valueFrom": "$(self).bam.md5",
                            "id": "#main/merge/md5_file_name"
                        },
                        {
                            "source": "#main/sample_name",
                            "valueFrom": "$(self).bam.bai",
                            "id": "#main/merge/out_bam_index_name"
                        },
                        {
                            "source": "#main/sample_name",
                            "valueFrom": "$(self).bam",
                            "id": "#main/merge/out_bam_name"
                        },
                        {
                            "source": "#main/map_and_stats/dup_marked_bam",
                            "id": "#main/merge/sorted_bams"
                        },
                        {
                            "source": "#main/merge_threads",
                            "id": "#main/merge/threads"
                        }
                    ],
                    "out": [
                        "#main/merge/dup_marked_merged_bam",
                        "#main/merge/dup_marked_bam_dup_met",
                        "#main/merge/dup_marked_bam_md5"
                    ],
                    "run": "#merge_and_mark_dups.cwl",
                    "id": "#main/merge"
                }
            ],
            "doc": "A workflow to generate mapping stats, gene counts and fusion events from RNA-seq data using cgpRna container. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:yx2@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/infuse/combined_fusions",
                    "id": "#main/combined_fusions"
                },
                {
                    "type": "File",
                    "outputSource": "#main/infuse/defuse_fusions",
                    "id": "#main/defuse_fusions"
                },
                {
                    "type": "File",
                    "outputSource": "#main/merge/dup_marked_merged_bam",
                    "id": "#main/dup_marked_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/merge/dup_marked_bam_dup_met",
                    "id": "#main/dup_marked_bam_dup_met"
                },
                {
                    "type": "File",
                    "outputSource": "#main/merge/dup_marked_bam_md5",
                    "id": "#main/dup_marked_bam_md5"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/dup_marked_bam_dup_met",
                    "id": "#main/dup_marked_lane_bam_dup_mets"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/gene_body_coverage_rscript",
                    "id": "#main/gene_body_coverage_rscripts"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/gene_body_coverage_txt",
                    "id": "#main/gene_body_coverage_txts"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/gene_body_coverage_updated_rscript",
                    "id": "#main/gene_body_coverage_updated_rscripts"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/gene_cover_png",
                    "id": "#main/gene_cover_pngs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bigwig/out_bw",
                    "id": "#main/out_bw"
                },
                {
                    "type": "File",
                    "outputSource": "#main/count/out_count",
                    "id": "#main/out_count"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/read_dist",
                    "id": "#main/read_dists"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/rna_bas",
                    "id": "#main/rna_bas_files"
                },
                {
                    "type": "File",
                    "outputSource": "#main/infuse/star_fusions",
                    "id": "#main/star_fusions"
                },
                {
                    "type": "File",
                    "outputSource": "#main/infuse/tophat_fusions",
                    "id": "#main/tophat_fusions"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map_and_stats/transcriptome_bam",
                    "id": "#main/transcriptome_lane_bams"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#infuse_pipeline.cwl",
            "label": "workflow to detect fusion events",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Defuse reference bundle tar file.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/defuse_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for tophat fusion process.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/defuse_threads"
                },
                {
                    "type": "File",
                    "doc": "GTF file which is used to annotate break points.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/gtf"
                },
                {
                    "type": "File",
                    "doc": "input BAM file.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/in_bam"
                },
                {
                    "type": "string",
                    "doc": "Sample name, which will used to prefix output file names.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/sample_name"
                },
                {
                    "type": "File",
                    "doc": "STAR reference bundle tar file.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/star_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for tophat fusion process.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/star_threads"
                },
                {
                    "type": "File",
                    "doc": "Tophat fusion reference bundle tar file.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "doc": "Number of threads to use for tophat fusion process.",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_threads"
                },
                {
                    "type": "File",
                    "doc": "VAGrENT cache file that should be the same reference and gene build as the GTF file.",
                    "secondaryFiles": [
                        ".tbi",
                        "$(self.basename.replace(\"cache.gz\", \"fa\"))",
                        "$(self.basename.replace(\"cache.gz\", \"fa.fai\"))"
                    ],
                    "id": "#infuse_pipeline.cwl/infuse-workflow/vagrent_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/output",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/combined_fusions"
                },
                {
                    "type": "File",
                    "outputSource": "#infuse_pipeline.cwl/infuse-workflow/defuse/output",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/defuse_fusions"
                },
                {
                    "type": "File",
                    "outputSource": "#infuse_pipeline.cwl/infuse-workflow/star_fusion/output",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/star_fusions"
                },
                {
                    "type": "File",
                    "outputSource": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion/output",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusions"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/in_bam",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/bam_to_fq/in_bam"
                        }
                    ],
                    "out": [
                        "#infuse_pipeline.cwl/infuse-workflow/bam_to_fq/output_fqs"
                    ],
                    "run": "#bam_to_fq.cwl",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/bam_to_fq"
                },
                {
                    "in": [
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/defuse/output",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/defuse_output"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/gtf",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/gtf"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/sample_name",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/sample_name"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/star_fusion/output",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/star_fusion_output"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion/output",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/tophat_fusion_output"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/vagrent_cache",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/vagrent_cache"
                        }
                    ],
                    "out": [
                        "#infuse_pipeline.cwl/infuse-workflow/combine_fusions/output"
                    ],
                    "run": "#compare_overlapping_fusions.cwl",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/combine_fusions"
                },
                {
                    "in": [
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/bam_to_fq/output_fqs",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/defuse/reads"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/defuse_reference",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/defuse/reference"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/sample_name",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/defuse/sample_name"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/defuse_threads",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/defuse/threads"
                        }
                    ],
                    "out": [
                        "#infuse_pipeline.cwl/infuse-workflow/defuse/output"
                    ],
                    "run": "#run-cgprna_defuse.cwl",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/defuse"
                },
                {
                    "in": [
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/bam_to_fq/output_fqs",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/star_fusion/reads"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/star_reference",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/star_fusion/reference"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/sample_name",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/star_fusion/sample_name"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/star_threads",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/star_fusion/threads"
                        }
                    ],
                    "out": [
                        "#infuse_pipeline.cwl/infuse-workflow/star_fusion/output"
                    ],
                    "run": "#run-cgprna_star-fusion.cwl",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/star_fusion"
                },
                {
                    "in": [
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/bam_to_fq/output_fqs",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion/reads"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion_reference",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion/reference"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/sample_name",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion/sample_name"
                        },
                        {
                            "source": "#infuse_pipeline.cwl/infuse-workflow/tophat_threads",
                            "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion/threads"
                        }
                    ],
                    "out": [
                        "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion/output"
                    ],
                    "run": "#run-cgprna_tophat-fusion.cwl",
                    "id": "#infuse_pipeline.cwl/infuse-workflow/tophat_fusion"
                }
            ],
            "doc": "A workflow to run cpgRna Infuse pipeline from a single input BAM file (can be aligned or unaligned) of RNA-seq reads using cgpRna container. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:yx2@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#bam_to_fq.cwl",
            "label": "convert bam to unzipped fq",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 8000
                }
            ],
            "inputs": [
                {
                    "doc": "input BAM.",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "filename=",
                        "separate": false
                    },
                    "id": "#bam_to_fq.cwl/bam-to-fq/in_bam"
                },
                {
                    "type": "string",
                    "doc": "output name of the fastq file containing second mate of matched pairs in the BAM.",
                    "default": "",
                    "inputBinding": {
                        "valueFrom": "${\n  var extension = \"matched.1_2.fq\";\n  var eles;\n  if (self) {\n    eles = [inputs.output_prefix, self, extension]\n  } else {\n    eles = [inputs.output_prefix, extension]\n  }\n  return eles.join(\".\")\n}\n",
                        "prefix": "F2=",
                        "separate": false
                    },
                    "id": "#bam_to_fq.cwl/bam-to-fq/matched_2_out_name"
                },
                {
                    "type": "string",
                    "doc": "output name of the fastq file containing first mate of matched pairs in the BAM.",
                    "default": "",
                    "inputBinding": {
                        "valueFrom": "${\n  var extension = \"matched.1_1.fq\";\n  var eles;\n  if (self) {\n    eles = [inputs.output_prefix, self, extension]\n  } else {\n    eles = [inputs.output_prefix, extension]\n  }\n  return eles.join(\".\")\n}\n",
                        "prefix": "F=",
                        "separate": false
                    },
                    "id": "#bam_to_fq.cwl/bam-to-fq/matched_out_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "bamtofastq_converted",
                    "id": "#bam_to_fq.cwl/bam-to-fq/output_prefix"
                },
                {
                    "type": "string",
                    "doc": "output name of the fastq file containing single-ended reads in the BAM.",
                    "default": "",
                    "inputBinding": {
                        "valueFrom": "${\n  var extension = \"singe_ended.fq\";\n  var eles;\n  if (self) {\n    eles = [inputs.output_prefix, self, extension]\n  } else {\n    eles = [inputs.output_prefix, extension]\n  }\n  return eles.join(\".\")\n}\n",
                        "prefix": "S=",
                        "separate": false
                    },
                    "id": "#bam_to_fq.cwl/bam-to-fq/single_end_out_name"
                },
                {
                    "type": "string",
                    "doc": "output name of the fastq file containing second mate of unmatched pairs in the BAM.",
                    "default": "",
                    "inputBinding": {
                        "valueFrom": "${\n  var extension = \"unmatched.1_2.fq\";\n  var eles;\n  if (self) {\n    eles = [inputs.output_prefix, self, extension]\n  } else {\n    eles = [inputs.output_prefix, extension]\n  }\n  return eles.join(\".\")\n}\n",
                        "prefix": "O2=",
                        "separate": false
                    },
                    "id": "#bam_to_fq.cwl/bam-to-fq/unmatcted_2_out_name"
                },
                {
                    "type": "string",
                    "doc": "output name of the fastq file containing first mate of unmatched pairs in the BAM.",
                    "default": "",
                    "inputBinding": {
                        "valueFrom": "${\n  var extension = \"unmatched.1_1.fq\";\n  var eles;\n  if (self) {\n    eles = [inputs.output_prefix, self, extension]\n  } else {\n    eles = [inputs.output_prefix, extension]\n  }\n  return eles.join(\".\")\n}\n",
                        "prefix": "O=",
                        "separate": false
                    },
                    "id": "#bam_to_fq.cwl/bam-to-fq/unmatcted_out_name"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.matched.1_[12].fq"
                    },
                    "id": "#bam_to_fq.cwl/bam-to-fq/output_fqs"
                }
            ],
            "baseCommand": [
                "bamtofastq",
                "exclude=SECONDARY,SUPPLEMENTARY"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#compare_overlapping_fusions.cwl",
            "label": "compare fusions",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Output file of tophat fusion, usually with suffix: '.defuse-fusion.normals.ext.filtered.txt'.",
                    "inputBinding": {
                        "shellQuote": true,
                        "position": 6
                    },
                    "id": "#compare_overlapping_fusions.cwl/run-cgprna_comp-fusions/defuse_output"
                },
                {
                    "type": "File",
                    "doc": "GTF file which is used to annotate break points.",
                    "inputBinding": {
                        "prefix": "-g",
                        "separate": true,
                        "shellQuote": true,
                        "position": 2
                    },
                    "id": "#compare_overlapping_fusions.cwl/run-cgprna_comp-fusions/gtf"
                },
                {
                    "type": "string",
                    "doc": "sample name which is used to name the output file.",
                    "inputBinding": {
                        "prefix": "-s",
                        "separate": true,
                        "shellQuote": true,
                        "position": 1
                    },
                    "id": "#compare_overlapping_fusions.cwl/run-cgprna_comp-fusions/sample_name"
                },
                {
                    "type": "File",
                    "doc": "Output file of Star fusion, usually with suffix: '.star-fusion.normals.filtered.txt'.",
                    "inputBinding": {
                        "shellQuote": true,
                        "position": 5
                    },
                    "id": "#compare_overlapping_fusions.cwl/run-cgprna_comp-fusions/star_fusion_output"
                },
                {
                    "type": "File",
                    "doc": "Output file of Tophat fusion, usually with suffix: '.tophat-fusion.normals.filtered.strand.txt'.",
                    "inputBinding": {
                        "shellQuote": true,
                        "position": 4
                    },
                    "id": "#compare_overlapping_fusions.cwl/run-cgprna_comp-fusions/tophat_fusion_output"
                },
                {
                    "type": "File",
                    "doc": "VAGrENT cache file that should be the same reference and gene build as the GTF file.",
                    "inputBinding": {
                        "prefix": "-c",
                        "separate": true,
                        "shellQuote": true,
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi",
                        "$(self.basename.replace(\"cache.gz\", \"fa\"))",
                        "$(self.basename.replace(\"cache.gz\", \"fa.fai\"))"
                    ],
                    "id": "#compare_overlapping_fusions.cwl/run-cgprna_comp-fusions/vagrent_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).infuse.detected.fusions.grass.txt"
                    },
                    "id": "#compare_overlapping_fusions.cwl/run-cgprna_comp-fusions/output"
                }
            ],
            "baseCommand": [
                "compare_overlapping_fusions.pl",
                "-o",
                "."
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#lane_map_and_stats.cwl",
            "label": "map raw reads to reference and generate QC stats",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/ds_tag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/lb_tag"
                },
                {
                    "type": "File",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/map_reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/map_threads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/pl_tag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/pu_tag"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/raw_reads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/rg_id_tag"
                },
                {
                    "type": "string",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/sample_name"
                },
                {
                    "type": "File",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/stats_reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/map/dup_marked_bam",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/dup_marked_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/map/dup_marked_bam_dup_met",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/dup_marked_bam_dup_met"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_body_coverage_rscript",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/gene_body_coverage_rscript"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_body_coverage_txt",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/gene_body_coverage_txt"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_body_coverage_updated_rscript",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/gene_body_coverage_updated_rscript"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_cover_png",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/gene_cover_png"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/stats/read_dist",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/read_dist"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/stats/rna_bas",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/rna_bas"
                },
                {
                    "type": "File",
                    "outputSource": "#lane_map_and_stats.cwl/lane-map-stats/map/star_transcriptome_bam",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/transcriptome_bam"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/ds_tag",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/ds_tag"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/lb_tag",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/lb_tag"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/sample_name",
                            "valueFrom": "${\n  return self + '.lane.' + inputs.raw_reads[0].nameroot;\n}\n",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/output_file_prefix"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/pl_tag",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/pl_tag"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/pu_tag",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/pu_tag"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/raw_reads",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/raw_reads"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/map_reference",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/reference"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/rg_id_tag",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/rg_id_tag"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/sample_name",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/sample_name"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/map_threads",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/map/threads"
                        }
                    ],
                    "out": [
                        "#lane_map_and_stats.cwl/lane-map-stats/map/star_transcriptome_bam",
                        "#lane_map_and_stats.cwl/lane-map-stats/map/dup_marked_bam",
                        "#lane_map_and_stats.cwl/lane-map-stats/map/dup_marked_bam_dup_met"
                    ],
                    "run": "#run-cgprna_star-map.cwl",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/map"
                },
                {
                    "in": [
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/stats_reference",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/stats/reference"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/map/dup_marked_bam",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/stats/sample_bam"
                        },
                        {
                            "source": "#lane_map_and_stats.cwl/lane-map-stats/map/star_transcriptome_bam",
                            "id": "#lane_map_and_stats.cwl/lane-map-stats/stats/transcriptome_bam"
                        }
                    ],
                    "out": [
                        "#lane_map_and_stats.cwl/lane-map-stats/stats/rna_bas",
                        "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_cover_png",
                        "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_body_coverage_rscript",
                        "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_body_coverage_txt",
                        "#lane_map_and_stats.cwl/lane-map-stats/stats/gene_body_coverage_updated_rscript",
                        "#lane_map_and_stats.cwl/lane-map-stats/stats/read_dist"
                    ],
                    "run": "#run-cgprna_stats.cwl",
                    "id": "#lane_map_and_stats.cwl/lane-map-stats/stats"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#merge_and_mark_dups.cwl",
            "label": "merge BAMs and mark dupliates",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 8000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out_merged.bam.met",
                    "inputBinding": {
                        "prefix": "M=",
                        "separate": false
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/dup_met_file_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out_merged.bam.md5",
                    "inputBinding": {
                        "prefix": "md5filename=",
                        "separate": false
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/md5_file_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "if specified, make sure it matches '{out_bam_name}.bai'.",
                    "default": "out_merged.bam.bai",
                    "inputBinding": {
                        "prefix": "indexfilename=",
                        "separate": false
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/out_bam_index_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out_merged.bam",
                    "inputBinding": {
                        "prefix": "O=",
                        "separate": false
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/out_bam_name"
                },
                {
                    "doc": "BAM files to be merged.",
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "I=",
                            "separate": false
                        }
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/sorted_bams"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of threads to use.",
                    "inputBinding": {
                        "prefix": "markthreads=",
                        "separate": false
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.md5_file_name)"
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/dup_marked_bam_dup_met"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.dup_met_file_name)"
                    },
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/dup_marked_bam_md5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_bam_name)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#merge_and_mark_dups.cwl/merge-mark-dups/dup_marked_merged_bam"
                }
            ],
            "baseCommand": [
                "bammarkduplicates2",
                "md5=1",
                "index=1"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run-cgprna_bigwig.cwl",
            "label": "cgpRna bigwig",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "FASTA file of a reference file, which the input BAM file was mapped to.",
                    "inputBinding": {
                        "prefix": "--reference",
                        "separate": true
                    },
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#run-cgprna_bigwig.cwl/run-cgprna_bigwig/reference"
                },
                {
                    "type": "File",
                    "doc": "Input BAM file, in which reads are mapped to a reference genome (NOT transcriptome).",
                    "inputBinding": {
                        "prefix": "--input",
                        "separate": true
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#run-cgprna_bigwig.cwl/run-cgprna_bigwig/sample_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of threads to use.",
                    "inputBinding": {
                        "prefix": "--threads",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_bigwig.cwl/run-cgprna_bigwig/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bw"
                    },
                    "id": "#run-cgprna_bigwig.cwl/run-cgprna_bigwig/out_bw"
                }
            ],
            "baseCommand": [
                "run-cgprna",
                "bigwig"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run-cgprna_defuse.cwl",
            "label": "cgpRna defuse",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 10000,
                    "outdirMin": 10000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "gene build folder name, if specified it'll be used to locate the folder within the reference bundle.",
                    "inputBinding": {
                        "prefix": "--gene-build",
                        "separate": true
                    },
                    "id": "#run-cgprna_defuse.cwl/run-cgprna_defuse/gene_build"
                },
                {
                    "doc": "RAW read input, can be bam files and FastQ files (optionally gzip compressed).",
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "itemSeparator": " "
                        }
                    },
                    "inputBinding": {
                        "prefix": "--input",
                        "separate": true
                    },
                    "id": "#run-cgprna_defuse.cwl/run-cgprna_defuse/reads"
                },
                {
                    "type": "File",
                    "doc": "The Tophat fusion reference files bundled in a tar.gz.",
                    "inputBinding": {
                        "prefix": "--reference",
                        "separate": true
                    },
                    "id": "#run-cgprna_defuse.cwl/run-cgprna_defuse/reference"
                },
                {
                    "type": "string",
                    "doc": "Sample name, which will used to prefix output file names and SM tag in the BAM file header.",
                    "inputBinding": {
                        "prefix": "--sample-name",
                        "separate": true
                    },
                    "id": "#run-cgprna_defuse.cwl/run-cgprna_defuse/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of threads to use.",
                    "inputBinding": {
                        "prefix": "--threads",
                        "separate": true
                    },
                    "id": "#run-cgprna_defuse.cwl/run-cgprna_defuse/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).defuse-fusion.normals.ext.filtered.txt"
                    },
                    "id": "#run-cgprna_defuse.cwl/run-cgprna_defuse/output"
                }
            ],
            "baseCommand": [
                "run-cgprna",
                "defuse"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run-cgprna_htseq-count.cwl",
            "label": "cgpRna htseq-count",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "A reference GTF file.",
                    "inputBinding": {
                        "prefix": "--reference",
                        "separate": true
                    },
                    "id": "#run-cgprna_htseq-count.cwl/run-cgprna_htseq-count/reference"
                },
                {
                    "type": "File",
                    "doc": "Input BAM file, in which reads are mapped to a reference genome (NOT transcriptome).",
                    "inputBinding": {
                        "prefix": "--input",
                        "separate": true
                    },
                    "id": "#run-cgprna_htseq-count.cwl/run-cgprna_htseq-count/sample_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "rna_htseqcount.gz"
                    },
                    "id": "#run-cgprna_htseq-count.cwl/run-cgprna_htseq-count/out_count"
                }
            ],
            "baseCommand": [
                "run-cgprna",
                "count"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run-cgprna_star-fusion.cwl",
            "label": "cgpRna star fusion",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 10000,
                    "outdirMin": 10000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "gene build folder name, if specified it'll be used to locate the folder within the reference bundle.",
                    "inputBinding": {
                        "prefix": "--gene-build",
                        "separate": true
                    },
                    "id": "#run-cgprna_star-fusion.cwl/run-cgprna_star-fusion/gene_build"
                },
                {
                    "doc": "RAW read input, can be bam files and FastQ files (optionally gzip compressed).",
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "itemSeparator": " "
                        }
                    },
                    "inputBinding": {
                        "prefix": "--input",
                        "separate": true
                    },
                    "id": "#run-cgprna_star-fusion.cwl/run-cgprna_star-fusion/reads"
                },
                {
                    "type": "File",
                    "doc": "The Tophat fusion reference files bundled in a tar.gz.",
                    "inputBinding": {
                        "prefix": "--reference",
                        "separate": true
                    },
                    "id": "#run-cgprna_star-fusion.cwl/run-cgprna_star-fusion/reference"
                },
                {
                    "type": "string",
                    "doc": "Sample name, which will used to prefix output file names and SM tag in the BAM file header.",
                    "inputBinding": {
                        "prefix": "--sample-name",
                        "separate": true
                    },
                    "id": "#run-cgprna_star-fusion.cwl/run-cgprna_star-fusion/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of threads to use.",
                    "inputBinding": {
                        "prefix": "--threads",
                        "separate": true
                    },
                    "id": "#run-cgprna_star-fusion.cwl/run-cgprna_star-fusion/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).star-fusion.normals.filtered.txt"
                    },
                    "id": "#run-cgprna_star-fusion.cwl/run-cgprna_star-fusion/output"
                }
            ],
            "baseCommand": [
                "run-cgprna",
                "star-fusion"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run-cgprna_star-map.cwl",
            "label": "cgpRna mapping",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 30000,
                    "outdirMin": 20000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Description tag value in the output BAM header. Default: None or taken from the input raw BAM file.",
                    "inputBinding": {
                        "prefix": "--ds-tag",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/ds_tag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Sequencing library tag value in the output BAM header. Default: None or taken from the input raw BAM file.",
                    "inputBinding": {
                        "prefix": "--lb-tag",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/lb_tag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output files prefix, if final outputs should have prefix different from sample_name. This should not contain any folder path.",
                    "inputBinding": {
                        "prefix": "--output-file-prefix",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/output_file_prefix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Platform tag value in the output BAM header. Default: None or taken from the input raw BAM file.",
                    "inputBinding": {
                        "prefix": "--pl-tag",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/pl_tag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Platform unit tag value in the output BAM header. Default: None or taken from the input raw BAM file.",
                    "inputBinding": {
                        "prefix": "--pu-tag",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/pu_tag"
                },
                {
                    "doc": "RAW read input, can be multiple bam files, or several pairs of FastQ files (optionally gzip compressed), but not a mixture of BAM and FastQs.",
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "itemSeparator": " "
                        }
                    },
                    "inputBinding": {
                        "prefix": "--input",
                        "separate": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/raw_reads"
                },
                {
                    "type": "File",
                    "doc": "The core STAR reference and a GTF file bundled in a tar.gz.",
                    "inputBinding": {
                        "prefix": "--reference",
                        "separate": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Readgroup ID tag value in the output BAM. Default: taken from the input raw BAM file or 1.",
                    "inputBinding": {
                        "prefix": "--rg-id-tag",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/rg_id_tag"
                },
                {
                    "type": "string",
                    "doc": "Sample name, which will used to prefix output file names and SM tag in the BAM file header.",
                    "default": "",
                    "inputBinding": {
                        "prefix": "--sample-name",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of threads to use.",
                    "inputBinding": {
                        "prefix": "--threads",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_file_prefix != null) {\n    return inputs.output_file_prefix + '.bam';\n  } else {\n    return inputs.sample_name + '.bam';\n  }\n}\n"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/dup_marked_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_file_prefix != null) {\n    return inputs.output_file_prefix + '.bam.met';\n  } else {\n    return inputs.sample_name + '.bam.met';\n  }\n}\n"
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/dup_marked_bam_dup_met"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_file_prefix != null) {\n    return inputs.output_file_prefix + '.bam.md5';\n  } else {\n    return inputs.sample_name + '.bam.md5';\n  }\n}\n"
                    },
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/dup_marked_bam_md5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_file_prefix != null) {\n    return inputs.output_file_prefix + '.star.AlignedtoTranscriptome.out.bam';\n  } else {\n    return inputs.sample_name + '.star.AlignedtoTranscriptome.out.bam';\n  }\n}\n"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#run-cgprna_star-map.cwl/run-cgprna_map/star_transcriptome_bam"
                }
            ],
            "baseCommand": [
                "run-cgprna",
                "map"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run-cgprna_stats.cwl",
            "label": "cgpRna stats",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 2000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "The reference files bundled in a tar.gz.",
                    "inputBinding": {
                        "prefix": "--reference",
                        "separate": true
                    },
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/reference"
                },
                {
                    "type": "File",
                    "doc": "Input BAM file, in which reads are mapped to a reference genome (NOT transcriptome)",
                    "inputBinding": {
                        "prefix": "--input",
                        "separate": true
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/sample_bam"
                },
                {
                    "type": "File",
                    "doc": "BAM file, in which reads are mapped to a reference transciptome (NOT genome).",
                    "inputBinding": {
                        "prefix": "--transcriptome-bam",
                        "separate": true
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/transcriptome_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_bam.nameroot).geneBodyCoverage.r"
                    },
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/gene_body_coverage_rscript"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_bam.nameroot).geneBodyCoverage.txt"
                    },
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/gene_body_coverage_txt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_bam.nameroot).geneBodyCoverage_UPDATED.r"
                    },
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/gene_body_coverage_updated_rscript"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_bam.nameroot).geneBodyCoverage.curves.png"
                    },
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/gene_cover_png"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_bam.nameroot).read_dist.txt"
                    },
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/read_dist"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_bam.nameroot).RNA.bas"
                    },
                    "id": "#run-cgprna_stats.cwl/run-cgprna_stats/rna_bas"
                }
            ],
            "baseCommand": [
                "run-cgprna",
                "stats"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#run-cgprna_tophat-fusion.cwl",
            "label": "cgpRna tophat fusion",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/cgprna/status)\nA Docker container for the cgpRna mapping flow. See the [cgpRna](https://github.com/cancerit/cgpRna) website for more information.\n\nPlease read the relevant [changes](https://github.com/cancerit/cgpRna/blob/dev/CHANGES.md) when upgrading.\n\nParameters for a CWL definition are generally described in a json file, but parameters can be provided on the command line.\n\nTo see the parameters descriptions please run: cwltool --tool-help path_to.cwl\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/cgprna:2.6.1"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 10000,
                    "outdirMin": 10000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "gene build folder name, if specified it'll be used to locate the folder within the reference bundle.",
                    "inputBinding": {
                        "prefix": "--gene-build",
                        "separate": true
                    },
                    "id": "#run-cgprna_tophat-fusion.cwl/run-cgprna_tophat-fusion/gene_build"
                },
                {
                    "doc": "RAW read input, can be bam files and FastQ files (optionally gzip compressed).",
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "itemSeparator": " "
                        }
                    },
                    "inputBinding": {
                        "prefix": "--input",
                        "separate": true
                    },
                    "id": "#run-cgprna_tophat-fusion.cwl/run-cgprna_tophat-fusion/reads"
                },
                {
                    "type": "File",
                    "doc": "The Tophat fusion reference files bundled in a tar.gz.",
                    "inputBinding": {
                        "prefix": "--reference"
                    },
                    "id": "#run-cgprna_tophat-fusion.cwl/run-cgprna_tophat-fusion/reference"
                },
                {
                    "type": "string",
                    "doc": "Sample name, which will used to prefix output file names and SM tag in the BAM file header.",
                    "inputBinding": {
                        "prefix": "--sample-name",
                        "separate": true
                    },
                    "id": "#run-cgprna_tophat-fusion.cwl/run-cgprna_tophat-fusion/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of threads to use.",
                    "inputBinding": {
                        "prefix": "--threads",
                        "separate": true
                    },
                    "id": "#run-cgprna_tophat-fusion.cwl/run-cgprna_tophat-fusion/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).tophat-fusion.normals.filtered.strand.txt"
                    },
                    "id": "#run-cgprna_tophat-fusion.cwl/run-cgprna_tophat-fusion/output"
                }
            ],
            "baseCommand": [
                "run-cgprna",
                "tophat-fusion"
            ],
            "http://schema.org/codeRepository": "https://github.com/cancerit/cgpRna",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0-only",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
